# MATH-533-F2023

# TODO list

Priority
- Doc
- Separate guide (how to) from documentation. refactor doc
- Add examples
- Upload to pypy
- Add instructions on how to install the module
- Gradient explosion warning